/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CustomFileFilter.java 20821 2011-02-02 16:59:06Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.autostart.utility;

import java.io.File;

import javax.swing.filechooser.FileFilter;

/**
 * Define a custom file filter.
 * @author skabore
 */
public class CustomFileFilter extends FileFilter {

    /**
     * The authorized extensions
     */
    private String[] extensions;

    /**
     * The description.
     */
    private String description;

    /**
     * Constructor.
     * @param extensions the authorized extensions
     * @param description the description.
     */
    public CustomFileFilter(final String[] extensions, final String description) {
        this.extensions = extensions;
        this.description = description;
    }

    /**
     * Check the extension is in the extensions list.
     * @param extension the extension to check.
     * @return true if the extension is in the extensions list, false otherwise.
     */
    boolean isInExtensionList(final String extension) {
        for (int i = 0; i < this.extensions.length; ++i) {
            if (extension.equals(this.extensions[i])) {
                return true;
            }
        }
        return false;
    }

    /**
     * Check if the file extension is accepted.
     * @param file the file to check.
     * @return true if the file extension is accepted, false otherwise.
     */
    @Override
    public boolean accept(final File file) {
        if (file.isDirectory()) {
            return true;
        }
        String extension = null;
        String s = file.getName();
        int i = s.lastIndexOf('.');
        if (i > 0 && i < s.length() - 1) {
            extension = s.substring(i + 1).toLowerCase();
        }
        return extension != null && isInExtensionList(extension);
    }

    /**
     * @return the description.
     */
    @Override
    public String getDescription() {
        return this.description;
    }
}
