/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Output.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.autostart.utility;

import java.util.ArrayList;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.swing.JLabel;
import javax.swing.JTextArea;

/**
 * This class writes message in the specified output.
 * @author skabore
 */
public class Output {

    /**
     * The logger where informations will be written.
     */
    private Logger logger;

    /**
     * The textarea where informations will be written.
     */
    private JTextArea textArea;

    /**
     * The textOutput where informations will be written.
     */
    private JLabel textOutput;

    /**
     * The outputFlex where informations will be written.
     */
    private ArrayList outputFlex;

    /**
     * Default constructor.
     */
    public Output() {
        this.logger = null;
        this.textArea = null;
        this.textOutput = null;
        this.outputFlex = null;
    }

    /**
     * Build a new Output class.
     * @param logger the logger.
     */
    public Output(final Logger logger) {
        new Output();
        this.logger = logger;
    }

    /**
     * Build a new Output class.
     * @param textArea the textarea.
     */
    public Output(final JTextArea textArea) {
        new Output();
        this.textArea = textArea;
    }

    /**
     * Build a new Output class.
     * @param textOutput the textOutput.
     */
    public Output(final JLabel textOutput) {
        new Output();
        this.textOutput = textOutput;
    }

    /**
     * Build a new Output class.
     * @param textOutput the textOutput.
     * @param textArea the textarea.
     */
    public Output(final JLabel textOutput, final JTextArea textArea) {
        new Output();
        this.textArea = textArea;
        this.textOutput = textOutput;
    }

    /**
     * Build a new Output class.
     * @param outputFlex the Flex output.
     */
    public Output(final ArrayList outputFlex) {
        new Output();
        this.outputFlex = outputFlex;
    }

    /**
     * Write a message.
     * @param message the message to write.
     */
    public void write(final String message) {
        if (logger != null) {
            logger.log(Level.INFO, message);
        } else if (textArea != null && textOutput == null) {
            textArea.setLineWrap(true);
            textArea.append(message + "\n");
            textArea.setCaretPosition(textArea.getDocument().getLength());
        } else if (textOutput != null && textArea == null) {
            textOutput.setText(message);
        } else if (textOutput != null && textArea != null) {
            textOutput.setText(message);
            textArea.setLineWrap(true);
            textArea.append(message + "\n");
            textArea.setCaretPosition(textArea.getDocument().getLength());
        } else if (outputFlex != null) {
            outputFlex.add(message);
        }
    }

    /**
     * @return outputFlex.
     */
    public ArrayList getOutputFlex() {
        return outputFlex;
    }
}
